% Auto-generated chapter 31 for abudawud
% Hadiths in this chapter: 43

\hadithdefcmd{abudawud}{3926}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو بَدْرٍ، حَدَّثَنِي أَبُو عُتْبَةَ، إِسْمَاعِيلُ بْنُ عَيَّاشٍ حَدَّثَنِي سُلَيْمَانُ بْنُ سُلَيْمٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُكَاتَبُ عَبْدٌ مَا بَقِيَ عَلَيْهِ مِنْ مُكَاتَبَتِهِ دِرْهَمٌ ‏"‏ ‏.‏\hadithno{3926}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Shu'aib: on his father's authority, told that his grandfather reported the Prophet (ﷺ) said: A slave who has entered into an agreement to purchase his freedom is a slave as long as a dirham of the agreed price remains to be paid}}
\hadithdefcmd{abudawud}{3927}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا عَبَّاسٌ الْجُرَيْرِيُّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا عَبْدٍ كَاتَبَ عَلَى مِائَةِ أُوقِيَّةٍ فَأَدَّاهَا إِلاَّ عَشْرَةَ أَوَاقٍ فَهُوَ عَبْدٌ وَأَيُّمَا عَبْدٍ كَاتَبَ عَلَى مِائَةِ دِينَارٍ فَأَدَّاهَا إِلاَّ عَشْرَةَ دَنَانِيرَ فَهُوَ عَبْدٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَيْسَ هُوَ عَبَّاسٌ الْجُرَيْرِيُّ قَالُوا هُوَ وَهَمٌ وَلَكِنَّهُ هُوَ شَيْخٌ آخَرُ ‏.‏\hadithno{3927}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Amr b. Shu'aib: On his father's authority, told that his grandfather reported the Prophet (ﷺ) said: If any slave entered into an agreement to buy his freedom for one hundred uqiyahs and he pays them all but ten, he remains a slave (until he pays the remaining ten); and if a slave entered into an agreement to purchase his freedom for one hundred dinars, and he pays them all but ten dinars, he remains a slave (until he pays the remaining ten). Abu Dawud said: This narrator 'Abbas al-Jariri is not the same person. They said: It is misunderstanding. He is some other narrator}}
\hadithdefcmd{abudawud}{3928}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ نَبْهَانَ، مُكَاتَبِ أُمِّ سَلَمَةَ قَالَ سَمِعْتُ أُمَّ سَلَمَةَ، تَقُولُ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ كَانَ لإِحْدَاكُنَّ مُكَاتَبٌ فَكَانَ عِنْدَهُ مَا يُؤَدِّي فَلْتَحْتَجِبْ مِنْهُ ‏"‏ ‏.‏\hadithno{3928}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The Messenger of Allah (ﷺ) said to us: If one of you has a slave, and he enters into an agreement to purchase his freedom, and can pay the full price, she must veil herself from him}}
\hadithdefcmd{abudawud}{3929}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، رضى الله عنها أَخْبَرَتْهُ أَنَّ بَرِيرَةَ جَاءَتْ عَائِشَةَ تَسْتَعِينُهَا فِي كِتَابَتِهَا وَلَمْ تَكُنْ قَضَتْ مِنْ كِتَابَتِهَا شَيْئًا فَقَالَتْ لَهَا عَائِشَةُ ارْجِعِي إِلَى أَهْلِكِ فَإِنْ أَحَبُّوا أَنْ أَقْضِيَ عَنْكِ كِتَابَتَكِ وَيَكُونَ وَلاَؤُكِ لِي فَعَلْتُ ‏.‏ فَذَكَرَتْ ذَلِكَ بَرِيرَةُ لأَهْلِهَا فَأَبَوْا وَقَالُوا إِنْ شَاءَتْ أَنْ تَحْتَسِبَ عَلَيْكِ فَلْتَفْعَلْ وَيَكُونَ لَنَا وَلاَؤُكِ ‏.‏ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ابْتَاعِي فَأَعْتِقِي فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا بَالُ أُنَاسٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَنِ اشْتَرَطَ شَرْطًا لَيْسَ فِي كِتَابِ اللَّهِ فَلَيْسَ لَهُ وَإِنْ شَرَطَهُ مِائَةَ مَرَّةٍ شَرْطُ اللَّهِ أَحَقُّ وَأَوْثَقُ ‏"‏ ‏.‏\hadithno{3929}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2661، 2717) Sahih Muslim (1504)}\hadithtrans{Urwah quoting from 'Aishah said that Barirah came to her seeking her help to purchase her freedom, and she did not pay anything for her freedom. 'Aishah said to her:Return to your people ; if you like that I make payment for the purchase of your freedom on your behalf and I shall have the right to inherit from you, I shall do so. Barirah mentioned it to her people, but they refused and said: If she wants to purchase your freedom for reward from Allah, she may do so, but the right to inherit from her shall be ours. She mentioned it to the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said: Purchase her (freedom) and set her free, for the right of inheritance belongs to only to the one who set a person free. The Messenger of Allah (ﷺ) then stood up and said: If anyone makes a condition which is not in Allah's Book, he has no right to it, even if he stipulates it hundred times. Allah's condition is more valid and binding}}
\hadithdefcmd{abudawud}{3930}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ جَاءَتْ بَرِيرَةُ لِتَسْتَعِينَ فِي كِتَابَتِهَا فَقَالَتْ إِنِّي كَاتَبْتُ أَهْلِي عَلَى تِسْعِ أَوَاقٍ فِي كُلِّ عَامٍ أُوقِيَّةٌ فَأَعِينِينِي ‏.‏ فَقَالَتْ إِنْ أَحَبَّ أَهْلُكِ أَنْ أَعُدَّهَا عَدَّةً وَاحِدَةً وَأُعْتِقَكِ وَيَكُونَ وَلاَؤُكِ لِي فَعَلْتُ ‏.‏ فَذَهَبَتْ إِلَى أَهْلِهَا وَسَاقَ الْحَدِيثَ نَحْوَ الزُّهْرِيِّ زَادَ فِي كَلاَمِ النَّبِيِّ صلى الله عليه وسلم فِي آخِرِهِ ‏ "‏ مَا بَالُ رِجَالٍ يَقُولُ أَحَدُهُمْ أَعْتِقْ يَا فُلاَنُ وَالْوَلاَءُ لِي إِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{3930}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2563) Sahih Muslim (1504)}\hadithtrans{Aishah said:Barirah came seeking my help to purchase her freedom. She said: I have arranged with my people to buy my freedom for nine 'uqiyahs: one to be paid annually. So help me. She ('Aishah) said: If your people are willing that I should count them ('uqiyahs) out to them all at one time and set you free and that I shall have the right to inherit from you, I shall do so. She then went to her people. The narrator then transmitted the rest of the tradition like the version of al-Zuhri. He added to the wordings of the Prophet (ﷺ) in the last: What is the matter with people that one of you says: Set free, O so-and-so, and the right of inheritance belongs to me. The right of inheritance belongs to the one who has set a person free}}
\hadithdefcmd{abudawud}{3931}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى أَبُو الأَصْبَغِ الْحَرَّانِيُّ، حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنِ ابْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ وَقَعَتْ جُوَيْرِيَةُ بِنْتُ الْحَارِثِ بْنِ الْمُصْطَلِقِ فِي سَهْمِ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ أَوِ ابْنِ عَمٍّ لَهُ فَكَاتَبَتْ عَلَى نَفْسِهَا وَكَانَتِ امْرَأَةً مَلاَّحَةً تَأْخُذُهَا الْعَيْنُ - قَالَتْ عَائِشَةُ رضى الله عنها - فَجَاءَتْ تَسْأَلُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي كِتَابَتِهَا فَلَمَّا قَامَتْ عَلَى الْبَابِ فَرَأَيْتُهَا كَرِهْتُ مَكَانَهَا وَعَرَفْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَيَرَى مِنْهَا مِثْلَ الَّذِي رَأَيْتُ فَقَالَتْ يَا رَسُولَ اللَّهِ أَنَا جُوَيْرِيَةُ بِنْتُ الْحَارِثِ وَإِنَّمَا كَانَ مِنْ أَمْرِي مَا لاَ يَخْفَى عَلَيْكَ وَإِنِّي وَقَعْتُ فِي سَهْمِ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ وَإِنِّي كَاتَبْتُ عَلَى نَفْسِي فَجِئْتُكَ أَسْأَلُكَ فِي كِتَابَتِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَهَلْ لَكِ إِلَى مَا هُوَ خَيْرٌ مِنْهُ ‏"‏ ‏.‏ قَالَتْ وَمَا هُوَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أُؤَدِّي عَنْكِ كِتَابَتَكِ وَأَتَزَوَّجُكِ ‏"‏ ‏.‏ قَالَتْ قَدْ فَعَلْتُ قَالَتْ فَتَسَامَعَ - تَعْنِي النَّاسَ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ تَزَوَّجَ جُوَيْرِيَةَ فَأَرْسَلُوا مَا فِي أَيْدِيهِمْ مِنَ السَّبْىِ فَأَعْتَقُوهُمْ وَقَالُوا أَصْهَارُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَا رَأَيْنَا امْرَأَةً كَانَتْ أَعْظَمَ بَرَكَةً عَلَى قَوْمِهَا مِنْهَا أُعْتِقَ فِي سَبَبِهَا مِائَةُ أَهْلِ بَيْتٍ مِنْ بَنِي الْمُصْطَلِقِ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حُجَّةٌ فِي أَنَّ الْوَلِيَّ هُوَ يُزَوِّجُ نَفْسَهُ ‏.‏\hadithno{3931}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Juwayriyyah, daughter of al-Harith ibn al-Mustaliq, fell to the lot of Thabit ibn Qays ibn Shammas, or to her cousin. She entered into an agreement to purchase her freedom. She was a very beautiful woman, most attractive to the eye. Aisha said: She then came to the Messenger of Allah (ﷺ) asking him for the purchase of her freedom. When she was standing at the door, I looked at her with disapproval. I realised that the Messenger of Allah (ﷺ) would look at her in the same way that I had looked. She said: Messenger of Allah, I am Juwayriyyah, daughter of al-Harith, and something has happened to me, which is not hidden from you. I have fallen to the lot of Thabit ibn Qays ibn Shammas, and I have entered into an agreement to purchase of my freedom. I have come to you to seek assistance for the purchase of my freedom. The Messenger of Allah (ﷺ) said: Are you inclined to that which is better? She asked: What is that, Messenger of Allah? He replied: I shall pay the price of your freedom on your behalf, and I shall marry you. She said: I shall do this. She (Aisha) said: The people then heard that the Messenger of Allah (ﷺ) had married Juwayriyyah. They released the captives in their possession and set them free, and said: They are the relatives of the Messenger of Allah (ﷺ) by marriage. We did not see any woman greater than Juwayriyyah who brought blessings to her people. One hundred families of Banu al-Mustaliq were set free on account of her. Abu dawud said: This evidence shows that a Muslim ruler may marry a slave woman himself}}
\hadithdefcmd{abudawud}{3932}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ سَعِيدِ بْنِ جُمْهَانَ، عَنْ سَفِينَةَ، قَالَ كُنْتُ مَمْلُوكًا لأُمِّ سَلَمَةَ فَقَالَتْ أُعْتِقُكَ وَأَشْتَرِطُ عَلَيْكَ أَنْ تَخْدُمَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا عِشْتَ ‏.‏ فَقُلْتُ إِنْ لَمْ تَشْتَرِطِي عَلَىَّ مَا فَارَقْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا عِشْتُ فَأَعْتَقَتْنِي وَاشْتَرَطَتْ عَلَىَّ ‏.‏\hadithno{3932}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Safinah said: I was a slave of Umm Salamah, and she said: I shall emancipate you, but I stipulate that you must serve the Messenger of Allah (ﷺ) as long as you live. I said: Even if you do not make a stipulation, I shall not leave the Messenger of Allah (ﷺ). She then emancipated me and made the stipulation with me}}
\hadithdefcmd{abudawud}{3933}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا هَمَّامٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، - الْمَعْنَى - أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، - قَالَ أَبُو الْوَلِيدِ - عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَعْتَقَ شِقْصًا لَهُ مِنْ غُلاَمٍ فَذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَيْسَ لِلَّهِ شَرِيكٌ ‏"‏ ‏.‏ زَادَ ابْنُ كَثِيرٍ فِي حَدِيثِهِ فَأَجَازَ النَّبِيُّ صلى الله عليه وسلم عِتْقَهُ ‏.‏\hadithno{3933}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu al-Malih: On his father's authority (this is AbulWalid's version): A man emancipated a share in a slave and the matter was mentioned to the Prophet (ﷺ). He said: Allah has no partner. Ibn Kathir added in his version: The Prophet (ﷺ) allowed his emancipation}}
\hadithdefcmd{abudawud}{3934}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، أَعْتَقَ شِقْصًا لَهُ مِنْ غُلاَمٍ فَأَجَازَ النَّبِيُّ صلى الله عليه وسلم عِتْقَهُ وَغَرَّمَهُ بَقِيَّةَ ثَمَنِهِ ‏.‏\hadithno{3934}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2527) Sahih Muslim (1503)}\hadithtrans{Narrated AbuHurayrah: A man emancipated his share in a slave. The Prophet (ﷺ) allowed his (full) emancipation, and required him to pay the rest of his price}}
\hadithdefcmd{abudawud}{3935}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عَلِيِّ بْنِ سُوَيْدٍ، حَدَّثَنَا رَوْحٌ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، بِإِسْنَادِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ مَمْلُوكًا بَيْنَهُ وَبَيْنَ آخَرَ فَعَلَيْهِ خَلاَصُهُ ‏"‏ ‏.‏ وَهَذَا لَفْظُ ابْنِ سُوَيْدٍ ‏.‏\hadithno{3935}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1502)}\hadithtrans{Qatadah narrated with his chain of narrators:The Prophet (ﷺ) said: If a man emancipates a slave shared by him with another man, his emancipation rests with him (who emancipated his share). This is the version of Ibn Suwaid}}
\hadithdefcmd{abudawud}{3936}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي ح، وَحَدَّثَنَا أَحْمَدُ بْنُ عَلِيِّ بْنِ سُوَيْدٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا هِشَامُ بْنُ أَبِي عَبْدِ اللَّهِ، عَنْ قَتَادَةَ، بِإِسْنَادِهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ نَصِيبًا لَهُ فِي مَمْلُوكٍ عَتَقَ مِنْ مَالِهِ إِنْ كَانَ لَهُ مَالٌ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ ابْنُ الْمُثَنَّى النَّضْرَ بْنَ أَنَسٍ وَهَذَا لَفْظُ ابْنِ سُوَيْدٍ ‏.‏\hadithno{3936}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Qatadah narrated with his chain of narrators. The Prophet (ﷺ) said:If anyone emancipates his share in a slave, he emancipates him (completely) by his property if he has property. The narrator Ibn al-Muthanna did not mention al-Nadr b. Anas. This is the version of Ibn Suwaid}}
\hadithdefcmd{abudawud}{3937}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، - يَعْنِي الْعَطَّارَ - حَدَّثَنَا قَتَادَةُ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شَقِيصًا فِي مَمْلُوكِهِ فَعَلَيْهِ أَنْ يُعْتِقَهُ كُلَّهُ إِنْ كَانَ لَهُ مَالٌ وَإِلاَّ اسْتُسْعِيَ الْعَبْدُ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3937}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying:If anyone emancipates a share in his slave, he should completely emancipate him if he has money; but if he has none, then slave will be required to work (to pay for his freedom), but he must not be overburdened}}
\hadithdefcmd{abudawud}{3938}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - ح وَحَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، - وَهَذَا لَفْظُهُ - عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَعْتَقَ شِقْصًا لَهُ - أَوْ شَقِيصًا لَهُ - فِي مَمْلُوكٍ فَخَلاَصُهُ عَلَيْهِ فِي مَالِهِ إِنْ كَانَ لَهُ مَالٌ فَإِنْ لَمْ يَكُنْ لَهُ مَالٌ قُوِّمَ الْعَبْدُ قِيمَةَ عَدْلٍ ثُمَّ اسْتُسْعِيَ لِصَاحِبِهِ فِي قِيمَتِهِ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ فِي حَدِيثِهِمَا جَمِيعًا ‏"‏ فَاسْتُسْعِيَ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏ وَهَذَا لَفْظُ عَلِيٍّ ‏.‏\hadithno{3938}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2527) Sahih Muslim (1503)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying:If anyone emancipates his share in a slave, he is to be completely emancipated by his money if he has money. But if he has no money, a fair price for the slave should be fixed, and the slave is required to work for his master according to the proportion of his price, but he must not be overburdened. Abu Dawud said: In the version of both the narrators the words are "he will be required to work and must not be overburdened". This is the version of 'Ali}}
\hadithdefcmd{abudawud}{3939}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، وَابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، بِإِسْنَادِهِ وَمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ رَوْحُ بْنُ عُبَادَةَ عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، لَمْ يَذْكُرِ السِّعَايَةَ وَرَوَاهُ جَرِيرُ بْنُ حَازِمٍ وَمُوسَى بْنُ خَلَفٍ جَمِيعًا عَنْ قَتَادَةَ، بِإِسْنَادِ يَزِيدَ بْنِ زُرَيْعٍ وَمَعْنَاهُ وَذَكَرَا فِيهِ السِّعَايَةَ ‏.‏\hadithno{3939}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above by Rawh b. 'Ubadah from Sa'id b. Abu 'Arubah. In this version he did not mention the words "the slave should be required to work." If has also been transmitted by Jarir b. Hazim and Musa b. Khalaf from Qatadah through the chain of Yazid b. Zurai' and to the same effect. In this version they mentioned the words "the slave should be required to work}}
\hadithdefcmd{abudawud}{3940}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي مَمْلُوكٍ أُقِيمَ عَلَيْهِ قِيمَةَ الْعَدْلِ فَأَعْطَى شُرَكَاءَهُ حِصَصَهُمْ وَأُعْتِقَ عَلَيْهِ الْعَبْدُ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏ ‏.‏\hadithno{3940}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2522) Sahih Muslim (1501)}\hadithtrans{Abd Allah b. 'Umar reported the Messenger of Allah (ﷺ) as saying:If anyone emancipates his share in slave, a fair price for the slave should be fixed, give his partners their shares, and the slave be thus emancipated. Otherwise he is emancipated to the extent of the share which he emancipated}}
\hadithdefcmd{abudawud}{3941}{حَدَّثَنَا مُؤَمَّلٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ قَالَ وَكَانَ نَافِعٌ رُبَّمَا قَالَ ‏ "‏ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏ وَرُبَّمَا لَمْ يَقُلْهُ ‏.‏\hadithno{3941}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1501)}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Umar to the same effect through a different chain of narrators. Nafi' sometimes said:He will be emancipated to the extent of the share which he emancipated, and sometimes he did not say these words}}
\hadithdefcmd{abudawud}{3942}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ قَالَ أَيُّوبُ فَلاَ أَدْرِي هُوَ فِي الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَوْ شَىْءٌ قَالَهُ نَافِعٌ وَإِلاَّ عَتَقَ مِنْهُ مَا عَتَقَ ‏.‏\hadithno{3942}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2524) Sahih Muslim (1501)}\hadithtrans{The tradition mentioned above has also been narrated by Ibn 'Umar from the Prophet (ﷺ). The narrator Ayyub said:I do not know whether the following words are part of the tradition of the Prophet (ﷺ) or Nafi' told them himself: "Otherwise he will be emancipated to the extent of the first man's share}}
\hadithdefcmd{abudawud}{3943}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شِرْكًا مِنْ مَمْلُوكٍ لَهُ فَعَلَيْهِ عِتْقُهُ كُلُّهُ إِنْ كَانَ لَهُ مَا يَبْلُغُ ثَمَنَهُ وَإِنْ لَمْ يَكُنْ لَهُ مَالٌ عَتَقَ نَصِيبُهُ ‏"‏ ‏.‏\hadithno{3943}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2523) Sahih Muslim (1501 After 1667)}\hadithtrans{Ibn 'Umar reported the Messenger of Allah (ﷺ) as saying:If anyone emancipates his share in a slave, he should emancipate him completely if he has enough money to pay the full price ; but if he has none, he will be emancipated to the extent of his share}}
\hadithdefcmd{abudawud}{3944}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى إِبْرَاهِيمَ بْنِ مُوسَى ‏.‏\hadithno{3944}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih Bukhari (2525) Sahih Muslim (1501)}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Umar from the Prophet (ﷺ) to the same effect as mentioned by Ibrahim b. Musa through a different chain}}
\hadithdefcmd{abudawud}{3945}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى مَالِكٍ وَلَمْ يَذْكُرْ ‏"‏ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏ انْتَهَى حَدِيثُهُ إِلَى ‏"‏ وَأُعْتِقَ عَلَيْهِ الْعَبْدُ ‏"‏ ‏.‏ عَلَى مَعْنَاهُ ‏.‏\hadithno{3945}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2503)}\hadithtrans{The tradition mentioned above has also been narrated by Ibn 'Umar through a different chain of transmitters to the same effect as mentioned by Malik. In this version there is no mention of the words "otherwise he will be emancipated to the extent of the first man's share." His version ends "and the slave be thus emancipated," to the same effect as he (Malik) mentioned}}
\hadithdefcmd{abudawud}{3946}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي عَبْدٍ عَتَقَ مِنْهُ مَا بَقِيَ فِي مَالِهِ إِذَا كَانَ لَهُ مَا يَبْلُغُ ثَمَنَ الْعَبْدِ ‏"‏ ‏.‏\hadithno{3946}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1501 After  1667)}\hadithtrans{Ibn 'Umar reported the Prophet (ﷺ) as saying:If a man emancipates his share in a slave, the rest will be emancipated by his money if he has enough money to pay the full price for him}}
\hadithdefcmd{abudawud}{3947}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ الْعَبْدُ بَيْنَ اثْنَيْنِ فَأَعْتَقَ أَحَدُهُمَا نَصِيبَهُ فَإِنْ كَانَ مُوسِرًا يُقَوَّمُ عَلَيْهِ قِيمَةً لاَ وَكْسَ وَلاَ شَطَطَ ثُمَّ يُعْتَقُ ‏"‏ ‏.‏\hadithno{3947}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2521) Sahih Muslim (1501 After  1667)}\hadithtrans{Ibn 'Umar reported the Prophet (ﷺ) as saying:If a man is shared by two men, and one of them emancipates his share, a price of the slave will be fixed, not more or less, and he will be emancipated by him in case he is rich}}
\hadithdefcmd{abudawud}{3948}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ خَالِدٍ، عَنْ أَبِي بِشْرٍ الْعَنْبَرِيِّ، عَنِ ابْنِ التَّلِبِّ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَعْتَقَ نَصِيبًا لَهُ مِنْ مَمْلُوكٍ فَلَمْ يُضَمِّنْهُ النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ أَحْمَدُ إِنَّمَا هُوَ بِالتَّاءِ - يَعْنِي التَّلِبَّ - وَكَانَ شُعْبَةُ أَلْثَغَ لَمْ يُبَيِّنِ التَّاءَ مِنَ الثَّاءِ ‏.‏\hadithno{3948}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated ath-Thalabb: On the authority of his father: A man emancipated his share in a slave. The Prophet (ﷺ) did not put the responsibility on him to emancipate the rest. Ahmad said: The name Ibn al-Thalabb is to be pronounced with a ta' (and not with tha). As Shu'bah could not pronounce ta, he said tha}}
\hadithdefcmd{abudawud}{3949}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَالَ مُوسَى فِي مَوْضِعٍ آخَرَ عَنْ سَمُرَةَ بْنِ جُنْدُبٍ فِيمَا يَحْسِبُ حَمَّادٌ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ مَلَكَ ذَا رَحِمٍ مَحْرَمٍ فَهُوَ حُرٌّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ عَنْ حَمَّادِ بْنِ سَلَمَةَ عَنْ قَتَادَةَ وَعَاصِمٍ عَنِ الْحَسَنِ عَنْ سَمُرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ ذَلِكَ الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَمْ يُحَدِّثْ ذَلِكَ الْحَدِيثَ إِلاَّ حَمَّادُ بْنُ سَلَمَةَ وَقَدْ شَكَّ فِيهِ ‏.‏\hadithno{3949}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Samurah: The Prophet (ﷺ) said: (The narrator Musa said in another place: From Samurah ibn Jundub as presumed by Hammad): If anyone gets possession of a relative who is within the prohibited degrees, that person becomes free. AbuDawud said: A similar tradition has also been transmitted by Samurah from the Prophet (ﷺ) through a different chain. Abu Dawud said: Only Hammad b. Salamah has transmitted this tradition and he had doubt in it}}
\hadithdefcmd{abudawud}{3950}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، - رضى الله عنه - قَالَ مَنْ مَلَكَ ذَا رَحِمٍ مَحْرَمٍ فَهُوَ حُرٌّ ‏.‏\hadithno{3950}\hadithgrade{Al-Albani: Daif Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Daif Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: Qatadah reported Umar ibn al-Khattab (may Allah be pleased with him) as saying: If anyone gets possession of a relative who is within the prohibited degrees, that person becomes free}}
\hadithdefcmd{abudawud}{3951}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، قَالَ مَنْ مَلَكَ ذَا رَحِمٍ مَحْرَمٍ فَهُوَ حُرٌّ ‏.‏\hadithno{3951}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Qatadah reported 'Umar b. al-Khattab (ra) as saying:If anyone gets possession of a relative who is within the prohibited degrees, that person becomes free}}
\hadithdefcmd{abudawud}{3952}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ جَابِرِ بْنِ زَيْدٍ، وَالْحَسَنِ، مِثْلَهُ ‏.‏ قَالَ أَبُو دَاوُدَ سَعِيدٌ أَحْفَظُ مِنْ حَمَّادٍ ‏.‏\hadithno{3952}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Jabir b. Zaid and al-Hasan through a different chain of narrators. Abu Dawud said:The narrator sa'id retained te tradition more carefully than Hammad}}
\hadithdefcmd{abudawud}{3953}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ خَطَّابِ بْنِ صَالِحٍ، مَوْلَى الأَنْصَارِيِّ عَنْ أُمِّهِ، عَنْ سَلاَمَةَ بِنْتِ مَعْقِلٍ، - امْرَأَةٍ مِنْ خَارِجَةِ قَيْسِ عَيْلاَنَ - قَالَتْ قَدِمَ بِي عَمِّي فِي الْجَاهِلِيَّةِ فَبَاعَنِي مِنَ الْحُبَابِ بْنِ عَمْرٍو أَخِي أَبِي الْيَسَرِ بْنِ عَمْرٍو فَوَلَدْتُ لَهُ عَبْدَ الرَّحْمَنِ بْنَ الْحُبَابِ ثُمَّ هَلَكَ فَقَالَتِ امْرَأَتُهُ الآنَ وَاللَّهِ تُبَاعِينَ فِي دَيْنِهِ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي امْرَأَةٌ مِنْ خَارِجَةِ قَيْسِ عَيْلاَنَ قَدِمَ بِي عَمِّي الْمَدِينَةَ فِي الْجَاهِلِيَّةِ فَبَاعَنِي مِنَ الْحُبَابِ بْنِ عَمْرٍو أَخِي أَبِي الْيَسَرِ بْنِ عَمْرٍو فَوَلَدْتُ لَهُ عَبْدَ الرَّحْمَنِ بْنَ الْحُبَابِ فَقَالَتِ امْرَأَتُهُ الآنَ وَاللَّهِ تُبَاعِينَ فِي دَيْنِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ وَلِيُّ الْحُبَابِ ‏"‏ ‏.‏ قِيلَ أَخُوهُ أَبُو الْيَسَرِ بْنُ عَمْرٍو فَبَعَثَ إِلَيْهِ فَقَالَ ‏"‏ أَعْتِقُوهَا فَإِذَا سَمِعْتُمْ بِرَقِيقٍ قَدِمَ عَلَىَّ فَأْتُونِي أُعَوِّضْكُمْ مِنْهَا ‏"‏ ‏.‏ قَالَتْ فَأَعْتَقُونِي وَقَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم رَقِيقٌ فَعَوَّضَهُمْ مِنِّي غُلاَمًا ‏.‏\hadithno{3953}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sulamah bint Ma'qil al-Qasiyyah: My uncle brought me (to Medina) in the pre-Islamic days. He sold me to al-Hubab ibn Amr, brother of AbulYusr ibn Amr. I bore a child, AbdurRahman ibn al-Hubab, to him and he (al-Hubab) then died. Thereupon his wife said: I swear by Allah, now you will be sold (as a repayment) for his loan. So I came to the Messenger of Allah (ﷺ) and said: Messenger of Allah! I am a woman of Banu Kharijah Qays ibn Aylan. My uncle had brought me to Medina in pre-Islamic days. He sold me to al-Hubab ibn Amr, brother of AbulYusr ibn Amr. I bore AbdurRahman ibn al-Hubab to him. His wife said: I swear by Allah, you will be sold for his loan. The Messenger of Allah (ﷺ) said: Who is the guardian of al-Hubab? He was told: His brother, AbulYusr ibn Amr. He then sent for him and said: Set her free; when you hear that some slaves have been brought to me, came to me, and I shall compensate you for her. She said: They set me free, and when some slaves were brought to the Messenger of Allah (ﷺ), he gave them a slave in compensation for me}}
\hadithdefcmd{abudawud}{3954}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ قَيْسٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بِعْنَا أُمَّهَاتِ الأَوْلاَدِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ فَلَمَّا كَانَ عُمَرُ نَهَانَا فَانْتَهَيْنَا ‏.‏\hadithno{3954}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: We sold slave-mothers during the time of the Messenger of Allah (ﷺ) and of AbuBakr. When Umar was in power, he forbade us and we stopped}}
\hadithdefcmd{abudawud}{3955}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، وَإِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، أَعْتَقَ غُلاَمًا لَهُ عَنْ دُبُرٍ مِنْهُ وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُ فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَبِيعَ بِسَبْعِمِائَةٍ أَوْ بِتِسْعِمِائَةٍ ‏.‏\hadithno{3955}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2230) Sahih Muslim (997 After 1668)}\hadithtrans{Jabir b. 'Abd Allah said:A man declared that his slave would be free after his death, but he had no other property. So the Prophet (ﷺ) ordered (to sell him). He was then sold for seven hundred or nine hundred (dirhams)}}
\hadithdefcmd{abudawud}{3956}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا بِشْرُ بْنُ بَكْرٍ، أَخْبَرَنَا الأَوْزَاعِيُّ، حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، بِهَذَا زَادَ وَقَالَ - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - ‏ "‏ أَنْتَ أَحَقُّ بِثَمَنِهِ وَاللَّهُ أَغْنَى عَنْهُ ‏"‏ ‏.‏\hadithno{3956}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above also has been transmitted by Jabir b. 'Abd Allah through a different chain of narrators. This version added:The Prophet (ﷺ) said: You are more entitled to his price, and Allah has no need of it}}
\hadithdefcmd{abudawud}{3957}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ يُقَالُ لَهُ أَبُو مَذْكُورٍ أَعْتَقَ غُلاَمًا لَهُ يُقَالُ لَهُ يَعْقُوبُ عَنْ دُبُرٍ وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُ فَدَعَا بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ يَشْتَرِيهِ ‏"‏ ‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ بْنِ النَّحَّامِ بِثَمَانِمِائَةِ دِرْهَمٍ فَدَفَعَهَا إِلَيْهِ ثُمَّ قَالَ ‏"‏ إِذَا كَانَ أَحَدُكُمْ فَقِيرًا فَلْيَبْدَأْ بِنَفْسِهِ فَإِنْ كَانَ فِيهَا فَضْلٌ فَعَلَى عِيَالِهِ فَإِنْ كَانَ فِيهَا فَضْلٌ فَعَلَى ذِي قَرَابَتِهِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ عَلَى ذِي رَحِمِهِ فَإِنْ كَانَ فَضْلاً فَهَا هُنَا وَهَا هُنَا ‏"‏ ‏.‏\hadithno{3957}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (997)}\hadithtrans{Jabir said:A man of the Ansar called Abu Madhkur declared that his slave called Ya'qub would be free after his death, but he had no other property. So the Messenger of Allah (ﷺ) called him and said: Who will buy him ? Nu'aim b. 'Abd Allah b. al-Nahham bought him for eight hundred dirhams. When he handed them over to him, he (Prophet) said: If any of you is poor, he should begin from himself ; if anything is left over, give it to your family; if anything is left over, give it to your relatives ; if anything is left over (when they received something), then here and here}}
\hadithdefcmd{abudawud}{3958}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، أَعْتَقَ سِتَّةَ أَعْبُدٍ عِنْدَ مَوْتِهِ وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُمْ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ لَهُ قَوْلاً شَدِيدًا ثُمَّ دَعَاهُمْ فَجَزَّأَهُمْ ثَلاَثَةَ أَجْزَاءٍ فَأَقْرَعَ بَيْنَهُمْ فَأَعْتَقَ اثْنَيْنِ وَأَرَقَّ أَرْبَعَةً ‏.‏\hadithno{3958}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1668)}\hadithtrans{Imran b. Hussain said:A man who had no other property emancipated six slaves of his at the time of the death. When the Prophet (ﷺ) was informed about it, he spoke severely of him. He then called them, divided them into three sections, cast lots among them, and emancipated two and kept four in slavery}}
\hadithdefcmd{abudawud}{3959}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ الْمُخْتَارِ - حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، بِإِسْنَادِهِ وَمَعْنَاهُ وَلَمْ يَقُلْ فَقَالَ لَهُ قَوْلاً شَدِيدًا ‏.‏\hadithno{3959}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Qilabah through a different chain of narrators on the authority of 'Imran b. Husain to the same effect. But in this version he did not mention "He spoke severely of them}}
\hadithdefcmd{abudawud}{3960}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، - هُوَ الطَّحَّانُ - عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي زَيْدٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ بِمَعْنَاهُ وَقَالَ - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - ‏ "‏ لَوْ شَهِدْتُهُ قَبْلَ أَنْ يُدْفَنَ لَمْ يُدْفَنْ فِي مَقَابِرِ الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{3960}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Qilabah from Abu Zaid through a different chain of narrators to the same effect:A man of the Ansar ... The Prophet (ﷺ) said: Had I been present before his burial, he would not have been buried in a Muslim cemetry}}
\hadithdefcmd{abudawud}{3961}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ عَتِيقٍ، وَأَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، أَعْتَقَ سِتَّةَ أَعْبُدٍ عِنْدَ مَوْتِهِ وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُمْ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَأَقْرَعَ بَيْنَهُمْ فَأَعْتَقَ اثْنَيْنِ وَأَرَقَّ أَرْبَعَةً ‏.‏\hadithno{3961}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim (1668)}\hadithtrans{Imran b. Husain said:A man emancipated six slaved at the time of his death and he had no other property. The Prophet (ﷺ) was informed about it. He cast lots among them, emancipated two and retained four in slavery}}
\hadithdefcmd{abudawud}{3962}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، وَاللَّيْثُ بْنُ سَعْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ عَبْدًا وَلَهُ مَالٌ فَمَالُ الْعَبْدِ لَهُ إِلاَّ أَنْ يَشْتَرِطَهُ السَّيِّدُ ‏"‏ ‏.‏\hadithno{3962}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (2379)}\hadithtrans{Abd Allah b. 'Umar reported the Messenger of Allah (ﷺ) as saying:If anyone emancipates a slave who has property, the property of the slave belongs to him except that the master makes a stipulation}}
\hadithdefcmd{abudawud}{3963}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا جَرِيرٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَلَدُ الزِّنَا شَرُّ الثَّلاَثَةِ ‏"‏ ‏.‏ وَقَالَ أَبُو هُرَيْرَةَ لأَنْ أُمَتِّعَ بِسَوْطٍ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ أَحَبُّ إِلَىَّ مِنْ أَنْ أَعْتِقَ وَلَدَ زِنْيَةٍ ‏.‏\hadithno{3963}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The child of adultery is worst of the three. Abu Hurairah said: That I give a flog in the path of Allah (as a charity) is dearer to me than emancipating a child of adultery}}
\hadithdefcmd{abudawud}{3964}{حَدَّثَنَا عِيسَى بْنُ مُحَمَّدٍ الرَّمْلِيُّ، حَدَّثَنَا ضَمْرَةُ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي عَبْلَةَ، عَنِ الْغَرِيفِ بْنِ الدَّيْلَمِيِّ، قَالَ أَتَيْنَا وَاثِلَةَ بْنَ الأَسْقَعِ فَقُلْنَا لَهُ حَدِّثْنَا حَدِيثًا، لَيْسَ فِيهِ زِيَادَةٌ وَلاَ نُقْصَانٌ فَغَضِبَ وَقَالَ إِنَّ أَحَدَكُمْ لَيَقْرَأُ وَمُصْحَفُهُ مُعَلَّقٌ فِي بَيْتِهِ فَيَزِيدُ وَيَنْقُصُ ‏.‏ قُلْنَا إِنَّمَا أَرَدْنَا حَدِيثًا سَمِعْتَهُ مِنَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فِي صَاحِبٍ لَنَا أَوْجَبَ - يَعْنِي - النَّارَ بِالْقَتْلِ فَقَالَ ‏ "‏ أَعْتِقُوا عَنْهُ يُعْتِقِ اللَّهُ بِكُلِّ عُضْوٍ مِنْهُ عُضْوًا مِنْهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{3964}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Wathilah ibn al-Asqa: Al-Arif ibn ad-Daylami said: We went to Wathilah ibn al-Asqa and said to him: Tell us a tradition which has not addition or omission. He became angry and replied: One of you recites when his copy of a Qur'an is hung up in his house, and he makes additions and omissions. We said: All we mean is a tradition you have heard from the Messenger of Allah (ﷺ). He said: We went to the Prophet (ﷺ) about a friend of ours who deserved. Hell for murder. He said: Emancipate a slave on his behalf; Allah will set free from Hell a member of the body for every member of his}}
\hadithdefcmd{abudawud}{3965}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمَرِيِّ، عَنْ أَبِي نَجِيحٍ السُّلَمِيِّ، قَالَ حَاصَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِقَصْرِ الطَّائِفِ - قَالَ مُعَاذٌ سَمِعْتُ أَبِي يَقُولُ بِقَصْرِ الطَّائِفِ بِحِصْنِ الطَّائِفِ كُلُّ ذَلِكَ - فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ بَلَغَ بِسَهْمٍ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ فَلَهُ دَرَجَةٌ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ وَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَيُّمَا رَجُلٍ مُسْلِمٍ أَعْتَقَ رَجُلاً مُسْلِمًا فَإِنَّ اللَّهَ عَزَّ وَجَلَّ جَاعِلٌ وِقَاءَ كُلِّ عَظْمٍ مِنْ عِظَامِهِ عَظْمًا مِنْ عِظَامِ مُحَرَّرِهِ مِنَ النَّارِ وَأَيُّمَا امْرَأَةٍ أَعْتَقَتِ امْرَأَةً مُسْلِمَةً فَإِنَّ اللَّهَ جَاعِلٌ وِقَاءَ كُلِّ عَظْمٍ مِنْ عِظَامِهَا عَظْمًا مِنْ عِظَامِ مُحَرَّرِهَا مِنَ النَّارِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3965}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuNajih as-Sulami: Along with the Messenger of Allah (ﷺ) we besieged the palace of at-Ta'if. The narrator, Mutadh, said: I heard my father (sometimes) say: "Palace of at-Ta'if," and (sometimes) "Fort of at-Ta'if," which are the same. I heard the Messenger of Allah (ﷺ) say: he who causes an arrow to hit its mark in Allah's cause will have it counted as a degree for him (in Paradise). He then transmitted the rest of the tradition. I heard the Messenger of Allah (ﷺ) say: If a Muslim man emancipates a Muslim man, Allah, the Exalted, will make every bone of his protection for every bone of his emancipator from Hell; and if a Muslim woman emancipates a Muslim woman, Allah will make every bone of hers protection for every bone of her emancipator from Hell on the Day of Resurrection}}
\hadithdefcmd{abudawud}{3966}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا صَفْوَانُ بْنُ عَمْرٍو، حَدَّثَنِي سُلَيْمُ بْنُ عَامِرٍ، عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، أَنَّهُ قَالَ لِعَمْرِو بْنِ عَبَسَةَ حَدِّثْنَا حَدِيثًا، سَمِعْتَهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَعْتَقَ رَقَبَةً مُؤْمِنَةً كَانَتْ فِدَاءَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{3966}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Amr ibn Abasah, said that Marrah ibn Ka'b said:I heard the Messenger of Allah (ﷺ) say: If anyone emancipates a Muslim slave, that will be his ransom from Jahannam}}
\hadithdefcmd{abudawud}{3967}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، أَنَّهُ قَالَ لِكَعْبِ بْنِ مُرَّةَ أَوْ مُرَّةَ بْنِ كَعْبٍ حَدِّثْنَا حَدِيثًا، سَمِعْتَهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مَعْنَى مُعَاذٍ إِلَى قَوْلِهِ ‏"‏ وَأَيُّمَا امْرِئٍ أَعْتَقَ مُسْلِمًا وَأَيُّمَا امْرَأَةٍ أَعْتَقَتِ امْرَأَةً مُسْلِمَةً ‏"‏ ‏.‏ زَادَ ‏"‏ وَأَيُّمَا رَجُلٍ أَعْتَقَ امْرَأَتَيْنِ مُسْلِمَتَيْنِ إِلاَّ كَانَتَا فِكَاكَهُ مِنَ النَّارِ يُجْزَى مَكَانَ كُلِّ عَظْمَيْنِ مِنْهُمَا عَظْمٌ مِنْ عِظَامِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَالِمٌ لَمْ يَسْمَعْ مِنْ شُرَحْبِيلَ مَاتَ شُرَحْبِيلُ بِصِفِّينَ ‏.‏\hadithno{3967}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Mu'adh through a different chain of narrators. After mentioning the words "If any Muslim emancipates a Muslim slave... and if a woman emancipates a Muslim woman, this version adds:"If a man emancipates two Muslim women, they will be deliverance from Hell fire; two bones of their will be emancipation for each of his bone." Abu Dawud said: Salim did not hear (traditions) from Shurahbil. Shurahbil died at Siffin}}
\hadithdefcmd{abudawud}{3968}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَبِيبَةَ الطَّائِيِّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الَّذِي يُعْتِقُ عِنْدَ الْمَوْتِ كَمَثَلِ الَّذِي يُهْدِي إِذَا شَبِعَ ‏"‏ ‏.‏\hadithno{3968}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbudDarda': The Prophet (ﷺ) said: the similitude of a man who emancipates a slave at the time of his death is like that of a man who gives a present after satisfying his appetite}}
